==> zio-aws-networkfirewall_3-5.19.17.1-sources.jar: zio/aws/networkfirewall/model/RuleGroupResponse.scala <==
package zio.aws.networkfirewall.model
import zio.aws.networkfirewall.model.primitives.{
  RuleCapacity,
  Description,
  ResourceArn,
  NumberOfAssociations,
  LastUpdateTime,
  ResourceId,
  ResourceName
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class RuleGroupResponse(
    ruleGroupArn: ResourceArn,
    ruleGroupName: ResourceName,
    ruleGroupId: ResourceId,
    description: Optional[Description] = Optional.Absent,
    `type`: Optional[zio.aws.networkfirewall.model.RuleGroupType] =
      Optional.Absent,
    capacity: Optional[RuleCapacity] = Optional.Absent,
    ruleGroupStatus: Optional[zio.aws.networkfirewall.model.ResourceStatus] =
      Optional.Absent,
    tags: Optional[Iterable[zio.aws.networkfirewall.model.Tag]] =
      Optional.Absent,
    consumedCapacity: Optional[RuleCapacity] = Optional.Absent,
    numberOfAssociations: Optional[NumberOfAssociations] = Optional.Absent,
    encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration
    ] = Optional.Absent,
    sourceMetadata: Optional[zio.aws.networkfirewall.model.SourceMetadata] =
      Optional.Absent,
    snsTopic: Optional[ResourceArn] = Optional.Absent,
    lastModifiedTime: Optional[LastUpdateTime] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse = {
    import RuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
      .builder()
      .ruleGroupArn(ResourceArn.unwrap(ruleGroupArn): java.lang.String)
      .ruleGroupName(ResourceName.unwrap(ruleGroupName): java.lang.String)
      .ruleGroupId(ResourceId.unwrap(ruleGroupId): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(
        capacity.map(value => RuleCapacity.unwrap(value): Integer)
      )(_.capacity)
      .optionallyWith(ruleGroupStatus.map(value => value.unwrap))(
        _.ruleGroupStatus
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        consumedCapacity.map(value => RuleCapacity.unwrap(value): Integer)
      )(_.consumedCapacity)
      .optionallyWith(
        numberOfAssociations.map(value =>
          NumberOfAssociations.unwrap(value): Integer
        )
      )(_.numberOfAssociations)
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(sourceMetadata.map(value => value.buildAwsValue()))(
        _.sourceMetadata
      )
      .optionallyWith(
        snsTopic.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.snsTopic)
      .optionallyWith(
        lastModifiedTime.map(value => LastUpdateTime.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .build()
  }
  def asReadOnly: zio.aws.networkfirewall.model.RuleGroupResponse.ReadOnly =
    zio.aws.networkfirewall.model.RuleGroupResponse.wrap(buildAwsValue())
}
object RuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkfirewall.model.RuleGroupResponse =
      zio.aws.networkfirewall.model.RuleGroupResponse(
        ruleGroupArn,
        ruleGroupName,
        ruleGroupId,
        description.map(value => value),
        `type`.map(value => value),
        capacity.map(value => value),
        ruleGroupStatus.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        consumedCapacity.map(value => value),
        numberOfAssociations.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        sourceMetadata.map(value => value.asEditable),
        snsTopic.map(value => value),
        lastModifiedTime.map(value => value)
      )
    def ruleGroupArn: ResourceArn
    def ruleGroupName: ResourceName
    def ruleGroupId: ResourceId
    def description: Optional[Description]
    def `type`: Optional[zio.aws.networkfirewall.model.RuleGroupType]
    def capacity: Optional[RuleCapacity]
    def ruleGroupStatus: Optional[zio.aws.networkfirewall.model.ResourceStatus]
    def tags: Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]]
    def consumedCapacity: Optional[RuleCapacity]
    def numberOfAssociations: Optional[NumberOfAssociations]
    def encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ]
    def sourceMetadata
        : Optional[zio.aws.networkfirewall.model.SourceMetadata.ReadOnly]
    def snsTopic: Optional[ResourceArn]
    def lastModifiedTime: Optional[LastUpdateTime]
    def getRuleGroupArn: ZIO[Any, Nothing, ResourceArn] =
      ZIO.succeed(ruleGroupArn)
    def getRuleGroupName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(ruleGroupName)
    def getRuleGroupId: ZIO[Any, Nothing, ResourceId] = ZIO.succeed(ruleGroupId)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getType
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.RuleGroupType] =
      AwsError.unwrapOptionField("type", `type`)
    def getCapacity: ZIO[Any, AwsError, RuleCapacity] =
      AwsError.unwrapOptionField("capacity", capacity)
    def getRuleGroupStatus
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.ResourceStatus] =
      AwsError.unwrapOptionField("ruleGroupStatus", ruleGroupStatus)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getConsumedCapacity: ZIO[Any, AwsError, RuleCapacity] =
      AwsError.unwrapOptionField("consumedCapacity", consumedCapacity)
    def getNumberOfAssociations: ZIO[Any, AwsError, NumberOfAssociations] =
      AwsError.unwrapOptionField("numberOfAssociations", numberOfAssociations)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getSourceMetadata: ZIO[
      Any,
      AwsError,
      zio.aws.networkfirewall.model.SourceMetadata.ReadOnly
    ] = AwsError.unwrapOptionField("sourceMetadata", sourceMetadata)
    def getSnsTopic: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("snsTopic", snsTopic)
    def getLastModifiedTime: ZIO[Any, AwsError, LastUpdateTime] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
  ) extends zio.aws.networkfirewall.model.RuleGroupResponse.ReadOnly {
    override val ruleGroupArn: ResourceArn =
      zio.aws.networkfirewall.model.primitives.ResourceArn(impl.ruleGroupArn())
    override val ruleGroupName: ResourceName =
      zio.aws.networkfirewall.model.primitives
        .ResourceName(impl.ruleGroupName())
    override val ruleGroupId: ResourceId =
      zio.aws.networkfirewall.model.primitives.ResourceId(impl.ruleGroupId())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.networkfirewall.model.primitives.Description(value))
    override val `type`: Optional[zio.aws.networkfirewall.model.RuleGroupType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.networkfirewall.model.RuleGroupType.wrap(value))
    override val capacity: Optional[RuleCapacity] = zio.aws.core.internal
      .optionalFromNullable(impl.capacity())
      .map(value =>
        zio.aws.networkfirewall.model.primitives.RuleCapacity(value)
      )
    override val ruleGroupStatus
        : Optional[zio.aws.networkfirewall.model.ResourceStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ruleGroupStatus())
        .map(value => zio.aws.networkfirewall.model.ResourceStatus.wrap(value))
    override val tags
        : Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.networkfirewall.model.Tag.wrap(item)
          }.toList
        )
    override val consumedCapacity: Optional[RuleCapacity] =
      zio.aws.core.internal
        .optionalFromNullable(impl.consumedCapacity())
        .map(value =>
          zio.aws.networkfirewall.model.primitives.RuleCapacity(value)
        )
    override val numberOfAssociations: Optional[NumberOfAssociations] =
      zio.aws.core.internal
        .optionalFromNullable(impl.numberOfAssociations())
        .map(value =>
          zio.aws.networkfirewall.model.primitives.NumberOfAssociations(value)
        )
    override val encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.encryptionConfiguration())
      .map(value =>
        zio.aws.networkfirewall.model.EncryptionConfiguration.wrap(value)
      )
    override val sourceMetadata
        : Optional[zio.aws.networkfirewall.model.SourceMetadata.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceMetadata())
        .map(value => zio.aws.networkfirewall.model.SourceMetadata.wrap(value))
    override val snsTopic: Optional[ResourceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.snsTopic())
      .map(value => zio.aws.networkfirewall.model.primitives.ResourceArn(value))
    override val lastModifiedTime: Optional[LastUpdateTime] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lastModifiedTime())
        .map(value =>
          zio.aws.networkfirewall.model.primitives.LastUpdateTime(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
  ): zio.aws.networkfirewall.model.RuleGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-networkfirewall_3-7.21.15.13-sources.jar: zio/aws/networkfirewall/model/RuleGroupResponse.scala <==
package zio.aws.networkfirewall.model
import zio.aws.networkfirewall.model.primitives.{
  RuleCapacity,
  Description,
  ResourceArn,
  NumberOfAssociations,
  LastUpdateTime,
  ResourceId,
  ResourceName
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class RuleGroupResponse(
    ruleGroupArn: ResourceArn,
    ruleGroupName: ResourceName,
    ruleGroupId: ResourceId,
    description: Optional[Description] = Optional.Absent,
    `type`: Optional[zio.aws.networkfirewall.model.RuleGroupType] =
      Optional.Absent,
    capacity: Optional[RuleCapacity] = Optional.Absent,
    ruleGroupStatus: Optional[zio.aws.networkfirewall.model.ResourceStatus] =
      Optional.Absent,
    tags: Optional[Iterable[zio.aws.networkfirewall.model.Tag]] =
      Optional.Absent,
    consumedCapacity: Optional[RuleCapacity] = Optional.Absent,
    numberOfAssociations: Optional[NumberOfAssociations] = Optional.Absent,
    encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration
    ] = Optional.Absent,
    sourceMetadata: Optional[zio.aws.networkfirewall.model.SourceMetadata] =
      Optional.Absent,
    snsTopic: Optional[ResourceArn] = Optional.Absent,
    lastModifiedTime: Optional[LastUpdateTime] = Optional.Absent,
    analysisResults: Optional[
      Iterable[zio.aws.networkfirewall.model.AnalysisResult]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse = {
    import RuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
      .builder()
      .ruleGroupArn(ResourceArn.unwrap(ruleGroupArn): java.lang.String)
      .ruleGroupName(ResourceName.unwrap(ruleGroupName): java.lang.String)
      .ruleGroupId(ResourceId.unwrap(ruleGroupId): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(
        capacity.map(value => RuleCapacity.unwrap(value): Integer)
      )(_.capacity)
      .optionallyWith(ruleGroupStatus.map(value => value.unwrap))(
        _.ruleGroupStatus
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        consumedCapacity.map(value => RuleCapacity.unwrap(value): Integer)
      )(_.consumedCapacity)
      .optionallyWith(
        numberOfAssociations.map(value =>
          NumberOfAssociations.unwrap(value): Integer
        )
      )(_.numberOfAssociations)
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(sourceMetadata.map(value => value.buildAwsValue()))(
        _.sourceMetadata
      )
      .optionallyWith(
        snsTopic.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.snsTopic)
      .optionallyWith(
        lastModifiedTime.map(value => LastUpdateTime.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .optionallyWith(
        analysisResults.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.analysisResults)
      .build()
  }
  def asReadOnly: zio.aws.networkfirewall.model.RuleGroupResponse.ReadOnly =
    zio.aws.networkfirewall.model.RuleGroupResponse.wrap(buildAwsValue())
}
object RuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkfirewall.model.RuleGroupResponse =
      zio.aws.networkfirewall.model.RuleGroupResponse(
        ruleGroupArn,
        ruleGroupName,
        ruleGroupId,
        description.map(value => value),
        `type`.map(value => value),
        capacity.map(value => value),
        ruleGroupStatus.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        consumedCapacity.map(value => value),
        numberOfAssociations.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        sourceMetadata.map(value => value.asEditable),
        snsTopic.map(value => value),
        lastModifiedTime.map(value => value),
        analysisResults.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def ruleGroupArn: ResourceArn
    def ruleGroupName: ResourceName
    def ruleGroupId: ResourceId
    def description: Optional[Description]
    def `type`: Optional[zio.aws.networkfirewall.model.RuleGroupType]
    def capacity: Optional[RuleCapacity]
    def ruleGroupStatus: Optional[zio.aws.networkfirewall.model.ResourceStatus]
    def tags: Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]]
    def consumedCapacity: Optional[RuleCapacity]
    def numberOfAssociations: Optional[NumberOfAssociations]
    def encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ]
    def sourceMetadata
        : Optional[zio.aws.networkfirewall.model.SourceMetadata.ReadOnly]
    def snsTopic: Optional[ResourceArn]
    def lastModifiedTime: Optional[LastUpdateTime]
    def analysisResults
        : Optional[List[zio.aws.networkfirewall.model.AnalysisResult.ReadOnly]]
    def getRuleGroupArn: ZIO[Any, Nothing, ResourceArn] =
      ZIO.succeed(ruleGroupArn)
    def getRuleGroupName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(ruleGroupName)
    def getRuleGroupId: ZIO[Any, Nothing, ResourceId] = ZIO.succeed(ruleGroupId)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getType
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.RuleGroupType] =
      AwsError.unwrapOptionField("type", `type`)
    def getCapacity: ZIO[Any, AwsError, RuleCapacity] =
      AwsError.unwrapOptionField("capacity", capacity)
    def getRuleGroupStatus
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.ResourceStatus] =
      AwsError.unwrapOptionField("ruleGroupStatus", ruleGroupStatus)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getConsumedCapacity: ZIO[Any, AwsError, RuleCapacity] =
      AwsError.unwrapOptionField("consumedCapacity", consumedCapacity)
    def getNumberOfAssociations: ZIO[Any, AwsError, NumberOfAssociations] =
      AwsError.unwrapOptionField("numberOfAssociations", numberOfAssociations)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getSourceMetadata: ZIO[
      Any,
      AwsError,
      zio.aws.networkfirewall.model.SourceMetadata.ReadOnly
    ] = AwsError.unwrapOptionField("sourceMetadata", sourceMetadata)
    def getSnsTopic: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("snsTopic", snsTopic)
    def getLastModifiedTime: ZIO[Any, AwsError, LastUpdateTime] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
    def getAnalysisResults: ZIO[Any, AwsError, List[
      zio.aws.networkfirewall.model.AnalysisResult.ReadOnly
    ]] = AwsError.unwrapOptionField("analysisResults", analysisResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
  ) extends zio.aws.networkfirewall.model.RuleGroupResponse.ReadOnly {
    override val ruleGroupArn: ResourceArn =
      zio.aws.networkfirewall.model.primitives.ResourceArn(impl.ruleGroupArn())
    override val ruleGroupName: ResourceName =
      zio.aws.networkfirewall.model.primitives
        .ResourceName(impl.ruleGroupName())
    override val ruleGroupId: ResourceId =
      zio.aws.networkfirewall.model.primitives.ResourceId(impl.ruleGroupId())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.networkfirewall.model.primitives.Description(value))
    override val `type`: Optional[zio.aws.networkfirewall.model.RuleGroupType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.networkfirewall.model.RuleGroupType.wrap(value))
    override val capacity: Optional[RuleCapacity] = zio.aws.core.internal
      .optionalFromNullable(impl.capacity())
      .map(value =>
        zio.aws.networkfirewall.model.primitives.RuleCapacity(value)
      )
    override val ruleGroupStatus
        : Optional[zio.aws.networkfirewall.model.ResourceStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ruleGroupStatus())
        .map(value => zio.aws.networkfirewall.model.ResourceStatus.wrap(value))
    override val tags
        : Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.networkfirewall.model.Tag.wrap(item)
          }.toList
        )
    override val consumedCapacity: Optional[RuleCapacity] =
      zio.aws.core.internal
        .optionalFromNullable(impl.consumedCapacity())
        .map(value =>
          zio.aws.networkfirewall.model.primitives.RuleCapacity(value)
        )
    override val numberOfAssociations: Optional[NumberOfAssociations] =
      zio.aws.core.internal
        .optionalFromNullable(impl.numberOfAssociations())
        .map(value =>
          zio.aws.networkfirewall.model.primitives.NumberOfAssociations(value)
        )
    override val encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.encryptionConfiguration())
      .map(value =>
        zio.aws.networkfirewall.model.EncryptionConfiguration.wrap(value)
      )
    override val sourceMetadata
        : Optional[zio.aws.networkfirewall.model.SourceMetadata.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceMetadata())
        .map(value => zio.aws.networkfirewall.model.SourceMetadata.wrap(value))
    override val snsTopic: Optional[ResourceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.snsTopic())
      .map(value => zio.aws.networkfirewall.model.primitives.ResourceArn(value))
    override val lastModifiedTime: Optional[LastUpdateTime] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lastModifiedTime())
        .map(value =>
          zio.aws.networkfirewall.model.primitives.LastUpdateTime(value)
        )
    override val analysisResults: Optional[
      List[zio.aws.networkfirewall.model.AnalysisResult.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.analysisResults())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.networkfirewall.model.AnalysisResult.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkfirewall.model.RuleGroupResponse
  ): zio.aws.networkfirewall.model.RuleGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}
